#
# spec file for package stm32flash
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           stm32flash
Version:        0.7
Release:        1.7
Summary:        Flash Program for the STM32 Bootloader
License:        GPL-2.0-or-later
Group:          Hardware/Other
URL:            https://sourceforge.net/p/stm32flash/wiki/Home
Source:         https://download.sourceforge.net/stm32flash/stm32flash-%{version}.tar.gz

%description
Open source flash program for the STM32 ARM processors using the ST
serial bootloader over UART or I2C.

Features:
- UART and I2C transports supported
- device identification
- write to flash/ram
- read from flash/ram
- auto-detect Intel HEX or raw binary input format with option to force
  binary
- flash from binary file
- save flash to binary file
- verify & retry up to N times on failed writes
- start execution at specified address
- software reset the device when finished if -R is specified
- resume already initialized connection (for when reset fails, UART only)
- GPIO signalling to enter bootloader mode (hardware dependent)

%prep
%setup -q

%build
%make_build CFLAGS="-O2 %{optflags}" PREFIX=%{_prefix}

%install
make %{?_smp_mflags} CFLAGS="-O2 %{optflags}" PREFIX=%{_prefix} DESTDIR=%{buildroot} install

%files
%license gpl-2.0.txt
%doc HOWTO I2C.txt protocol.txt TODO
%{_bindir}/stm32flash
%{_mandir}/man1/stm32flash.1*

%changelog
* Mon Feb 13 2023 Torsten Gruner <simmphonie@opensuse.org>
- update to 0.7
  * Fix I2C page-by-page erase (Yann Sionneau)
  * Fix hex file base address not used, extraneous base padding (Renaud Fivet)
  * Fix truncated read from stdin (Renaud Fivet)
  * Fix input buffer flush on Windows (Jan Belohoubek)
  * More baud rates available, up to 4000000
  * Allow skipping serial port setup with -b 0
  * Support STM32L412xx/422xx (Andy Little)
  * Support STM32G05xxx/061xx (Luca Amati), STM32G0B0/B1/C1xx, STM32G491xx/A1xx
- drop stm32flash-i2c-tools-headers-clash.patch
* Wed May 12 2021 Dirk Müller <dmueller@suse.com>
- update to 0.6:
  * Many more devices supported G0/G4/F7/H7/L4
  * GPIO sequencing reworked
  * Serial port handling improved
  * Many code improvements
  * Only erase needed pages if flashing from file
- drop 0001-Fix-for-device-0x442-System-memory-start-address.patch,
  0003-dev_table-Mark-0x417-0x429-0x427-for-no-mass-erase.patch: upstream
* Sat Aug 13 2016 kkaempf@suse.com
- add upstream fixes
  * Fix for device 0x442: System memory start address:
    0001-Fix-for-device-0x442-System-memory-start-address.patch
  * dev_table: Mark 0x417, 0x429, 0x427 for no mass-erase
    0003-dev_table-Mark-0x417-0x429-0x427-for-no-mass-erase.patch
* Sat Aug 13 2016 kkaempf@suse.com
- Update to 0.5
  * support for multiple bank sizes
  * improved serial port support on Windows
  * improved erase functionality
  * improved hex parser
  * many new devices and device info corrections
* Wed Oct 14 2015 dmitry_r@opensuse.org
- Restore i2c patch for released openSUSE versions (boo#952646)
* Wed Oct 14 2015 dvaleev@suse.com
- Drop stm32flash-i2c-tools-headers-clash.patch fixed in i2c-tools
* Fri Jun  5 2015 sbrabec@suse.cz
- New package, version 0.4.
- Fix i2c headers clash (stm32flash-i2c-tools-headers-clash.patch).
